@@ -139,6 +139,9 @@ class Recommendations:
                 Defaults to `None`, which is treated as an empty list.
         """
         commands = commands or []
+        if not isinstance(commands, list):
+            print_warning(f"commands are ignored (should be a list).")
+            commands = []
         current = set(self.db_programs)
         print(f"\nProcessing {len(commands)} commands on {len(current)} programs.")
 
@@ -151,6 +154,9 @@ class Recommendations:
             except KeyError:
                 print_warning(f"operation {i} is ignored (not specified).")
                 continue
+            except TypeError:
+                print_warning(f"operation {i} is ignored (malformed).")
+                continue
             (operation, n) = regex.subn(" all", "", operation)
             quantifier = "all" if n == 1 else "any"
             operation = Operation(operation.replace(" any", ""))
@@ -329,4 +335,4 @@ if __name__ == "__main__":
     rec.run_pipeline(ast.literal_eval(Path(f"{path}_pipe.py").read_text()))
     output_path = Path(f"{path}_recommendations.md")
     output_path.write_text(rec.get_markdown())
-    print(f"Dumped: {output_path.resolve()}.\n")
+    print(f"Dumped: {output_path.resolve()}\n")
